@@ -99,12 +99,18 @@ TrailGPXRecorder::TrailGPXRecorder(TrailInterface *interface, QWidget *parent) :
     m_poly = new QGeoMapPolylineObject();
     m_poly->setPen(QPen(Qt::red));
 
+    QList<QGeoCoordinate> invalid;
+    invalid << QGeoCoordinate() << QGeoCoordinate();
+    m_poly->setPath(invalid);
+
     m_currentCircle->setCenter(QGeoCoordinate(54.612293,-3.227448));
     m_currentCircle->setRadius(15);
     m_currentCircle->setPen(QPen(Qt::red, 3));
     m_currentCircle->setBrush(QBrush(QColor(128,0,0,128)));
 
     addMapObject(m_currentCircle, false);
+    addMapObject(m_poly, false);
+
     m_mapWidget->setCenter(m_currentCircle->center());
 }
 
@@ -168,13 +174,13 @@ void TrailGPXRecorder::positionUpdated(const QGeoPositionInfo& pos)
 
     m_currentCircle->setCenter(pos.coordinate());
 
-    m_path << QGeoCoordinate(pos.coordinate());
+    m_path.clear();
+
+    for (int i = 0; i < m_model->rowCount(); ++i) {
+        m_path << QGeoCoordinate(m_model->data(m_model->index(i, 2)).toDouble(), m_model->data(m_model->index(i, 2)).toDouble());
+    }
 
     m_poly->setPath(m_path);
-
-    m_mapWidget->clearMapObjects();
-    addMapObject(m_poly, false);
-    addMapObject(m_currentCircle, false);
     m_mapWidget->setCenter(m_currentCircle->center());
 }
 
