@@ -18,6 +18,10 @@ const QString TrailInterface::secret = QString("cf8282a798c96cc4");
 TrailInterface::TrailInterface()
 {
     m_networkManager = new QNetworkAccessManager();
+
+    m_serviceProvider = new QtMobility::QGeoServiceProvider("nokia");
+    m_mapManager = m_serviceProvider->mappingManager();
+
     connect(m_networkManager, SIGNAL(authenticationRequired(QNetworkReply*,QAuthenticator*)), this, SLOT(slotAuthenticationRequired(QNetworkReply*,QAuthenticator*)));
     connect(m_networkManager, SIGNAL(finished(QNetworkReply*)), this, SLOT(slotReplyFinished(QNetworkReply*)));
 
